What is SuperPyLib?

SuperPyLib is a Python package for calculating 2-D integral and finite element numerical solutions for Poisson equation with non-overlapping shapes in the presence of Superconducting materials. Rectified problem with parameter string in PlotUtils showSolution method and added underscore infront of parameter value in naming format of saved files.

Dependencies:

Python 3.8+, Numpy 1.23.1, Joblib 1.1.0, Matplotlib 3.5.2, Shapely 1.8.4, Triangle 20220202 and Scipy 1.8.1

Version:

SuperPyLib 0.0.8
